---
date: 2026-01-26 23:05:20
categories:
  - Releases
---

# Version v0.1.84

This version introduces a new feature that improves navigation by allowing users to zoom directly to a node when it is selected from a search, enhancing the user experience.

## New Features

- Added the ability to zoom to a node upon search selection, similar to using the 'z' key (b90da0) (Eric Ma)

## Bug Fixes

- None

## Deprecations

- None
